Image

Struct Image 

pub struct Image {
    pub prompt: Option<String>,
    pub n: Option<u64>,
    pub size: Option<String>,
    pub response_format: Option<String>,
    pub user: Option<String>,
    pub image: Option<String>,
    pub mask: Option<String>,
}
Represents an Image object in the OpenAI Image API.

This struct includes fields like prompt, n, size, response_format, user, image, and mask. Each of these fields can be set according to the requirements of the Image API request. Optional fields are represented as Option<T>.

For more information check the official openAI API documentation

Fields

prompt: Option<String>

A text description of the desired image(s). The maximum length is 1000 characters.

n: Option<u64>

The number of images to generate. Must be between 1 and 10.

size: Option<String>

The size of the generated images. Must be one of 256x256, 512x512, or 1024x1024.

response_format: Option<String>

The format in which the generated images are returned. Must be of type ImageResponseFormat.

user: Option<String>

A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse

image: Option<String>

Note: Only for edit/variation requests!

The image to edit. Must be a valid PNG file, less than 4MB, and square. If mask is not provided, image must have transparency, which will be used as the mask.

mask: Option<String>

Note: Only for edit requests!

An additional image whose fully transparent areas (e.g. where alpha is zero) indicate where image should be edited. Must be a valid PNG file, less than 4MB, and have the same dimensions as image.

Implementations

Source

impl Image

pub fn get_default_n() -> u64

Returns the default n for the Image API.

Returns

This function returns a u64 value which represents the default n.

pub fn get_default_size() -> &'static str

Returns the default image size for the Image API.

Returns

This function returns a &'static str value which represents the default size.

pub fn get_default_response_format() -> &'static str

Returns the default response data type for the Image API.

Returns

This function returns a &'static str value which represents the default response data type.

pub fn is_valid_size(size: &str) -> bool

Checks if the current Image object is valid in terms of its size fields

Returns

This function returns a bool value which represents whether the Image size is valid.

pub fn is_valid_response_format(response_format: &str) -> bool

Checks if the current Image object is valid in terms of the requested response format

Returns

This function returns a bool value which represents whether the Image response format is valid.

pub fn is_valid_n(n: u64) -> bool

Checks if the current Image object is valid in terms of its n field

Returns

This function returns a bool value which represents whether the Image n is valid.